@@ -2,27 +2,33 @@
 use strict;
 use warnings;
 
+my $target = shift || die("Pass target as first param\n");
+my $port   = shift || die("Pass port as second param\n");
+
+use Net::Frame::Device;
+
 use Net::Write::Layer3;
 use Net::Frame::Simple;
-use Net::Frame::Dump;
+use Net::Frame::Dump::Online;
 
 use Net::Frame::IPv4;
 use Net::Frame::TCP;
 
-my $ip4 = Net::Frame::IPv4->new;
+my $oDevice = Net::Frame::Device->new(target => $target);
+
+my $ip4 = Net::Frame::IPv4->new(
+   src => $oDevice->ip,
+   dst => $target,
+);
 my $tcp = Net::Frame::TCP->new(
-   dst     => 22,
+   dst     => $port,
    options => "\x02\x04\x54\x0b",
    payload => 'test',
 );
 
-my $oWrite = Net::Write::Layer3->new(
-   dst => '127.0.0.1',
-);
+my $oWrite = Net::Write::Layer3->new(dst => $target);
 
-my $oDump = Net::Frame::Dump->new(
-   dev => 'lo',
-);
+my $oDump = Net::Frame::Dump::Online->new(dev => $oDevice->dev);
 $oDump->start;
 
 my $oSimple = Net::Frame::Simple->new(
@@ -40,4 +46,3 @@ until ($oDump->timeout) {
 }
 
 $oDump->stop;
-$oDump->clean;
