@@ -2,8 +2,6 @@
 use strict;
 use warnings;
 
-my $target = shift || die("Specify target\n");
-
 use Net::Frame::Device;
 use Net::Frame::Simple;
 
@@ -11,15 +9,15 @@ use Net::Frame::ETH;
 use Net::Frame::IPv4;
 use Net::Frame::TCP;
 
-my $oDevice = Net::Frame::Device->new(target => $target);
+my $oDevice = Net::Frame::Device->new(target => $ARGV[0]);
 
 my $eth = Net::Frame::ETH->new(
    src => $oDevice->mac,
-   dst => $oDevice->lookupMac($target),
+   dst => $oDevice->lookupMac($ARGV[0]),
 );
 my $ip4 = Net::Frame::IPv4->new(
    src => $oDevice->ip,
-   dst => $target,
+   dst => $ARGV[0],
 );
 my $tcp = Net::Frame::TCP->new(
    options => "\x02\x04\x54\x0b",
